@@ -70,20 +70,16 @@ def get_expecting(lark_terminal_list):
 
 
 TERMINALS = {
-    "ACCESSION": "accession (e.g., NG_012337)",
-    "VERSION": "version (e.g., '1')",
-    "GENE_NAME": "gene name (e.g., SDHD)",
-    "GENBANK_LOCUS_SELECTOR": "genbank locus selector (e.g., v001, i001)",
-    "LRG_LOCUS": "lrg specific locus (e.g., p1, t1)",
-    "COORDINATE_SYSTEM": "a coordinate system: " "'g', 'o', 'm', 'c', 'n', 'r', or 'p'",
+    "ID": "a reference / selector ID",
+    "COORDINATE_SYSTEM": "a coordinate system, e.g., 'g', 'o', 'm', 'c', 'n', 'r', or 'p'",
     "POSITION": "position (e.g., 100)",
     "OFFSET": "position offset ('-' or '+')",
     "OUTSIDE_CDS": "'*' or '-' for an outside CDS location",
     "DOT": "'.' between the coordinate system and the operation(s)",
     "COLON": "':' between the reference part and the coordinate system",
     "UNDERSCORE": "'_' between start and end in range or uncertain positions",
-    "LPAR": "'(' for an uncertainty start",
-    "RPAR": "')' for an uncertainty end",
+    "LPAR": "'(' for an uncertainty start or before a selector ID",
+    "RPAR": "')' for an uncertainty end or after a selector ID",
     "SEMICOLON": "';' to separate variants",
     "LSQB": "'[' for multiple variants, insertions, or repeats",
     "RSQB": "']' for multiple variants, insertions, or repeats",
